@@ -130,7 +130,8 @@ int calc_variogram(VARIOGRAM *v /* pointer to VARIOGRAM structure */,
 	if (d2->sel == NULL)
 		select_at(d2, NULL);
 
-	if (v->ev->evt == CROSSVARIOGRAM && v->ev->is_asym == -1) {
+	if (v->ev->evt == CROSSVARIOGRAM && 
+			(v->ev->pseudo == -1 || v->ev->is_asym == -1)) {
 		/* v's first time */
 		if (coordinates_are_equal(d[v->id1], d[v->id2]))
 			v->ev->pseudo = 0;
